@@ -23,6 +23,8 @@ class AuthField(BaseModel):
     dataType: DataType = DataType.STRING
     label: Optional[str]
     required: bool = True
+    defaultValue: Optional[str]
+    description: Optional[str]
 
 class AuthMetadata(BaseModel):
     """
@@ -51,6 +53,7 @@ class SynapseInfo(BaseModel):
     supportedAuthTypes: List[AuthMetadata]
     configuredFields: Optional[List[AuthField]]
     disabledMessage: Optional[str]
+    oauthInfo: Optional[dict[str, str]]
 
 class AuthConfig(BaseModel):
     """
@@ -69,6 +72,22 @@ class AuthConfig(BaseModel):
     lastRefreshed: Optional[datetime]
     additionalHeaders: Optional[dict[str, str]]
 
+class OAuthRequest(BaseModel):
+    """
+        The authentication configuration for OAuth mechanism.
+    """
+    code: str
+    endpoint: str
+    redirectUri: str
+    authConfig: AuthConfig
+    metaConfig: Optional[dict[str, object]]
+
+    class Config:
+        """
+            allow for object validation workaround
+        """
+        arbitrary_types_allowed = True
+
 class Connection(BaseModel):
     """
         The connection information object.
