@@ -79,16 +79,19 @@ class SyncariRestClient:
         try:
             req = requests.Request(method, url, **kwargs).prepare()
             resp = self._session.send(req, stream=stream)
+            logger.info("%s: HTTP %s %s",resp.status_code, method, url)
         except Exception as e:
+            logger.error("Request to %s failed, payload %s error %s", url,
+                         kwargs, e)
             raise SyncariException(error_response=ErrorResponse(message=err_msg, detail=str(e), status_code=400))
 
         if resp.status_code == 500:
-            logger.error(resp)
+            logger.error("Request to %s failed with status code %s, payload %s response %s",url, resp.status_code,kwargs, resp.text)
             raise RetryableException(resp)
 
         if resp.status_code not in self.success_responses:
+            logger.error("Request to %s failed with status code %s, payload %s response %s",url, resp.status_code,kwargs, resp.text)
             error_resp = ErrorResponse(message=err_msg, detail=self.__get_error_response_details(resp), status_code=resp.status_code)
-            logger.error(error_resp)
             raise SyncariException(error_response=error_resp)
 
         return resp
